@@ -7,6 +7,11 @@ test_that("Checking a data set works",{
    expect_equal(checkRows(edt, dat), c(TRUE,FALSE))
 })
 
+test_that("Checking a vector works",{
+   edt <- editmatrix(editrules = "2*x==y")
+   dat <- c(x=2, y=1)
+   expect_equal(as.logical(violatedEdits(edt, dat)), c(TRUE))
+})
 
 test_that("Showing data errors works",{
    edt <- editmatrix(editrules = "2*x==y\n5*x==y")
@@ -14,8 +19,8 @@ test_that("Showing data errors works",{
    errors <- violatedEdits(edt, dat)
    
    # rule names equal?
-   print(dat)
-   print(errors)
+   #print(dat)
+   #print(errors)
    expect_equal(colnames(errors), rownames(edt))
    
    dimnames(errors) <- NULL
