@@ -18,8 +18,9 @@ test_that("editmatrix can simplify",{
             , "w == 3"
 			   )
 			
-   mat <- editmatrix(editrules=cond)
-   C <- getC(mat)
+   E <- editmatrix(editrules=cond)
+   mat <- getMatrix(E)
+   C <- getC(E)
    expect_equal(as.integer(mat[1,]), c(1,-1,0,0))
    expect_equal(as.integer(mat[2,]), c(0,-1,1,0))
    expect_equal(C[2], c(e2=1))
@@ -49,10 +50,11 @@ test_that("editmatrix works with constants",{
    cond <- c( "x + y > 2"
             , "y < 10"
             )
-   mat <- editmatrix(cond)
+   E <- editmatrix(editrules=cond)
+   mat <- getMatrix(E)
    expect_equal(as.integer(mat[1,]), c(1,1))
    expect_equal(as.integer(mat[2,]), c(0,1))
-   expect_equal(as.integer(getC(mat)), c(2,10))
+   expect_equal(as.integer(getC(E)), c(2,10))
 })
 
 test_that("conditional statement parsing is not working..",{
@@ -63,24 +65,26 @@ test_that("editmatrix works with negative constants",{
    cond <- c( "x + y > -2"
             , "y < -10"
             )
-   mat <- editmatrix(cond)
+   E <- editmatrix(editrules=cond)
+   mat <- getMatrix(E)
    expect_equal(as.integer(mat[1,]), c(1,1))
    expect_equal(as.integer(mat[2,]), c(0,1))
-   expect_equal(as.integer(getC(mat)), c(-2,-10))
+   expect_equal(as.integer(getC(E)), c(-2,-10))
 })
 
 test_that("editmatrix works with negative coefficients",{
    cond <- c( "-2*x + y > 2"
             )
-   mat <- editmatrix(editrules=cond)
+   E <- editmatrix(editrules=cond)
+   mat <- getMatrix(E)
    expect_equivalent(mat[1,], c(-2,1))
-   expect_equivalent(getC(mat), c(2))
+   expect_equivalent(getC(E), c(2))
 })
 
 test_that("editmatrix fails with nonconstant coefficient",{
    cond <- c( "a*x == 2"
             )
-   mat <- editmatrix(editrules=cond)
+   E <- editmatrix(editrules=cond)
 })
 
 
@@ -117,14 +121,15 @@ test_that("editmatrix normalize works",{
 			   , "x + z <= y + 2*w"
 			   )
 			
-   mat <- editmatrix(editrules=cond, normalize=TRUE)
-   print(mat)
+   E <- editmatrix(editrules=cond, normalize=TRUE)
+   mat <- getMatrix(E)
    
    expect_equivalent(mat[1,], c(-1,1,0,0))
    expect_equivalent(mat[2,], c(1,1,-1,-1))
    expect_equivalent(mat[3,], c(1,-1,-2,1))
    expect_equivalent(mat[4,], c(1,-1,-2,1))
    expect_equivalent(mat[5,], c(1,-1,-2,1))
-   ops <- getOps(mat)
-   expect_equivalent(ops, c("<=", "<", "<","==", "<="))
+   ops <- getOps(E)
+   #print(ops)
+   expect_equivalent(ops, c("<", "<=", "<","==", "<="))
 })
\ No newline at end of file
